@@ -1,4 +1,5 @@
 from .game import Game
 from .game import Action
 from .game import Feedback
-from .mazeGenerator import Maze
+from .mazeGenerator import MazeGenerator
+from .assessor import Assessor
