@@ -26,8 +26,7 @@ class GUI:
         self.endCt = 0
 
     def scale(self, value):
-        res = int(1 / (math.sqrt(value) + 1) * 1000)
-        print(1 / (math.sqrt(value) + 1))
+        res = int(1 / (math.sqrt(value) + 1) * 1100)
         return res
 
     '''
@@ -88,7 +87,6 @@ class GUI:
         squareWidth = self.scale(len(self.squareToDisplay))
         self.endCt = 0
         if not self.disp:
-            print(self.height)
             size = width, height = self.height * squareWidth, self.width * squareWidth
             self.screen = pygame.display.set_mode(size)
             pygame.display.set_caption("DonatelloPyzza")
